==> openshift-model-6.8.1-sources.jar: io/fabric8/openshift/api/model/BuildStatusOutputToFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BuildStatusOutputToFluent<A extends BuildStatusOutputToFluent<A>> extends BaseFluent<A>{
  public BuildStatusOutputToFluent() {
  }
  public BuildStatusOutputToFluent(BuildStatusOutputTo instance) {
    instance = (instance != null ? instance : new BuildStatusOutputTo());

    if (instance != null) {
      this.withImageDigest(instance.getImageDigest());
      this.withImageDigest(instance.getImageDigest());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String imageDigest;
  private Map<String,Object> additionalProperties;
  public String getImageDigest() {
    return this.imageDigest;
  }
  public A withImageDigest(String imageDigest) {
    this.imageDigest=imageDigest; return (A) this;
  }
  public boolean hasImageDigest() {
    return this.imageDigest != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BuildStatusOutputToFluent that = (BuildStatusOutputToFluent) o;
    if (!java.util.Objects.equals(imageDigest, that.imageDigest)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(imageDigest,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (imageDigest != null) { sb.append("imageDigest:"); sb.append(imageDigest + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-6.9.0-sources.jar: io/fabric8/openshift/api/model/BuildStatusOutputToFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class BuildStatusOutputToFluent<A extends BuildStatusOutputToFluent<A>> extends BaseFluent<A>{
  public BuildStatusOutputToFluent() {
  }
  
  public BuildStatusOutputToFluent(BuildStatusOutputTo instance) {
    this.copyInstance(instance);
  }
  private String imageDigest;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(BuildStatusOutputTo instance) {
    instance = (instance != null ? instance : new BuildStatusOutputTo());
  
    if (instance != null) {
        this.withImageDigest(instance.getImageDigest());
        this.withImageDigest(instance.getImageDigest());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getImageDigest() {
    return this.imageDigest;
  }
  
  public A withImageDigest(String imageDigest) {
    this.imageDigest=imageDigest; return (A) this;
  }
  
  public boolean hasImageDigest() {
    return this.imageDigest != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BuildStatusOutputToFluent that = (BuildStatusOutputToFluent) o;
    if (!java.util.Objects.equals(imageDigest, that.imageDigest)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(imageDigest,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (imageDigest != null) { sb.append("imageDigest:"); sb.append(imageDigest + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
